This dataset contains the results of the first round of the 2021 Chilean presidential elections. It provides
9 possible voting options (7 candidates, blank, and null). Each ballot-box is identified by its id (BALLOT.BOX) and an electoral circumscription
(ELECTORAL.DISTRICT). Additionally, it provides demographic information on voters' age range for each ballot box.
data("chile_election_2021")A data frame with 46,639 rows and 14 variables:
REGIONThe region of the ELECTORAL.DISTRICT
ELECTORAL.DISTRICTThe electoral circumscription of the ballot box.
BALLOT.BOXAn identifier for the ballot box within the ELECTORAL.DISTRICT.
C1The number of votes cast for the candidate Gabriel Boric.
C2The number of votes cast for the candidate José Antonio Kast.
C3The number of votes cast for the candidate Yasna Provoste.
C4The number of votes cast for the candidate Sebastián Sichel.
C5The number of votes cast for the candidate Eduardo Artés.
C6The number of votes cast for the candidate Marco Enríquez-Ominami.
C7The number of votes cast for the candidate Franco Parisi.
BLANK.VOTESThe number of blank votes.
NULL.VOTESThe number of null votes.
X18.19Number of voters aged 18--19.
X20.29Number of voters aged 20--29.
X30.39Number of voters aged 30--39.
X40.49Number of voters aged 40--49.
X50.59Number of voters aged 50--59.
X60.69Number of voters aged 60--69.
X70.79Number of voters aged 70--79.
X80.Number of voters aged 80 and older.
MISMATCHBoolean that takes value TRUE if the ballot-box has a mismatch between the total number of votes and the total number of voters. If this is not the case, its value is FALSE.
FNumber of female voters in the ballot box.
MNumber of male voters in the ballot box.
data("chile_election_2021")
head(chile_election_2021)
Run the code above in your browser using DataLab